# Vyro Documentation

Vyro combines Python DX with a Rust execution engine for high-performance APIs.

## What you can do

- Build async APIs with `Vyro()`
- Run services with `vyro run`
- Generate API contracts with OpenAPI
- Operate production services with observability and security primitives

## Start here

1. Read [Installation](getting-started/installation.md)
2. Follow [Quickstart](getting-started/quickstart.md)
3. Build your first endpoint in [First API](getting-started/first-api.md)
